@@ -24,6 +24,7 @@
 #include "gda-mysql-ddl.h"
 #include <glib/gi18n-lib.h>
 #include <libgda/gda-data-handler.h>
+#include <libgda/sql-parser/gda-sql-parser.h>
 
 gchar *
 gda_mysql_render_CREATE_DB (GdaServerProvider *provider, GdaConnection *cnc, 
@@ -33,6 +34,7 @@ gda_mysql_render_CREATE_DB (GdaServerProvider *provider, GdaConnection *cnc,
 	const GValue *value;
 	gchar *sql = NULL;
 	gboolean first = TRUE;
+	gchar *tmp;
 
 	string = g_string_new ("CREATE DATABASE ");
 
@@ -40,9 +42,9 @@ gda_mysql_render_CREATE_DB (GdaServerProvider *provider, GdaConnection *cnc,
 	if (value && G_VALUE_HOLDS (value, G_TYPE_BOOLEAN) && g_value_get_boolean (value))
 		g_string_append (string, "IF NOT EXISTS ");
 
-	value = gda_server_operation_get_value_at (op, "/DB_DEF_P/DB_NAME");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
-	g_string_append (string, g_value_get_string (value));
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/DB_DEF_P/DB_NAME");
+	g_string_append (string, tmp);
+	g_free (tmp);
 
 	value = gda_server_operation_get_value_at (op, "/DB_DEF_P/DB_CSET");
 	if (value && G_VALUE_HOLDS (value, G_TYPE_STRING) && g_value_get_string (value)) {
@@ -51,20 +53,21 @@ gda_mysql_render_CREATE_DB (GdaServerProvider *provider, GdaConnection *cnc,
 		first = FALSE;
 	}
 
-	value = gda_server_operation_get_value_at (op, "/DB_DEF_P/DB_COLLATION");
-	if (value && G_VALUE_HOLDS (value, G_TYPE_STRING) && g_value_get_string (value)) {
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/DB_DEF_P/DB_COLLATION");
+	if (tmp) {
 		if (first)
 			first = FALSE;
 		else
 			g_string_append (string, ", ");
 		g_string_append (string, " COLLATION ");
-		g_string_append (string, g_value_get_string (value));
+		g_string_append (string, tmp);
+		g_free (tmp);
 	}
 
 	sql = string->str;
 	g_string_free (string, FALSE);
 
-	return sql;	
+	return sql;
 }
 
 gchar *
@@ -74,6 +77,7 @@ gda_mysql_render_DROP_DB (GdaServerProvider *provider, GdaConnection *cnc,
 	GString *string;
 	const GValue *value;
 	gchar *sql = NULL;
+	gchar *tmp;
 
 	string = g_string_new ("DROP DATABASE ");
 
@@ -81,9 +85,9 @@ gda_mysql_render_DROP_DB (GdaServerProvider *provider, GdaConnection *cnc,
 	if (value && G_VALUE_HOLDS (value, G_TYPE_BOOLEAN) && g_value_get_boolean (value))
 		g_string_append (string, "IF EXISTS ");
 
-	value = gda_server_operation_get_value_at (op, "/DB_DESC_P/DB_NAME");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
-	g_string_append (string, g_value_get_string (value));
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/DB_DESC_P/DB_NAME");
+	g_string_append (string, tmp);
+	g_free (tmp);
 
 	sql = string->str;
 	g_string_free (string, FALSE);
@@ -106,6 +110,7 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 	GSList *pkfields = NULL; /* list of GValue* composing the pkey */
 	gint nbpkfields = 0;
 	gchar *sql = NULL;
+	gchar *tmp;
 
 	string = g_string_new ("CREATE ");
 	value = gda_server_operation_get_value_at (op, "/TABLE_DEF_P/TABLE_TEMP");
@@ -117,9 +122,9 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 	if (value && G_VALUE_HOLDS (value, G_TYPE_BOOLEAN) && g_value_get_boolean (value))
 		g_string_append (string, "IF NOT EXISTS ");
 		
-	value = gda_server_operation_get_value_at (op, "/TABLE_DEF_P/TABLE_NAME");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
-	g_string_append (string, g_value_get_string (value));
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/TABLE_DEF_P/TABLE_NAME");
+	g_string_append (string, tmp);
+	g_free (tmp);
 	g_string_append (string, " (");
 		
 	/* FIELDS */
@@ -133,11 +138,13 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 		nrows = gda_data_model_get_n_rows (node->model);
 		for (i = 0; i < nrows; i++) {
 			value = gda_server_operation_get_value_at (op, "/FIELDS_A/@COLUMN_PKEY/%d", i);
-			if (value && G_VALUE_HOLDS (value, G_TYPE_BOOLEAN) && g_value_get_boolean (value))
-				pkfields = g_slist_append (pkfields,
-							   (GValue *) gda_server_operation_get_value_at (op, "/FIELDS_A/@COLUMN_NAME/%d", i));
+			if (value && G_VALUE_HOLDS (value, G_TYPE_BOOLEAN) && g_value_get_boolean (value)) {
+				tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, 
+										  "/FIELDS_A/@COLUMN_NAME/%d", i);
+				pkfields = g_slist_append (pkfields, tmp);
+				nbpkfields ++;
+			}
 		}
-		nbpkfields = g_slist_length (pkfields);
 
 		/* manually defined fields */
 		first = TRUE;
@@ -148,8 +155,10 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 			else
 				g_string_append (string, ", ");
 				
-			value = gda_server_operation_get_value_at (op, "/FIELDS_A/@COLUMN_NAME/%d", i);
-			g_string_append (string, g_value_get_string (value));
+			tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider,
+									  "/FIELDS_A/@COLUMN_NAME/%d", i);
+			g_string_append (string, tmp);
+			g_free (tmp);
 			g_string_append_c (string, ' ');
 				
 			value = gda_server_operation_get_value_at (op, "/FIELDS_A/@COLUMN_TYPE/%d", i);
@@ -226,14 +235,15 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 		GSList *list = pkfields;
 
 		g_string_append (string, ", PRIMARY KEY (");
-		while (list) {
+		for (list = pkfields; list; list = list->next) {
 			if (list != pkfields)
 				g_string_append (string, ", ");
-			g_string_append (string, g_value_get_string ((GValue*) list->data));
-			list = list->next;
+			g_string_append (string, (gchar *) tmp);
 		}
 		g_string_append_c (string, ')');
 	}
+	g_slist_foreach (pkfields, (GFunc) g_free, NULL);
+	g_slist_free (pkfields);
 
 	/* foreign keys */
 	if (allok) {
@@ -250,43 +260,50 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 				node = gda_server_operation_get_node_info (op, "/FKEY_S/%d/FKEY_FIELDS_A", i);
 				if (!node || ((nbfields = gda_data_model_get_n_rows (node->model)) == 0)) {
 					allok = FALSE;
-					g_set_error (error, 0, 0, _("No field specified in foreign key constraint"));
+					g_set_error (error, 0, 0, "%s", _("No field specified in foreign key constraint"));
 				}
 				else {
 					for (j = 0; j < nbfields; j++) {
 						if (j != 0)
 							g_string_append (string, ", ");
-						value = gda_server_operation_get_value_at (op, 
-											   "/FKEY_S/%d/FKEY_FIELDS_A/@FK_FIELD/%d", i, j);
-						if (value && G_VALUE_HOLDS (value, G_TYPE_STRING) && g_value_get_string (value))
-							g_string_append (string, g_value_get_string (value));
+						tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider,
+												  "/FKEY_S/%d/FKEY_FIELDS_A/@FK_FIELD/%d", i, j);
+						if (tmp) {
+							g_string_append (string, tmp);
+							g_free (tmp);
+						}
 						else {
 							allok = FALSE;
-							g_set_error (error, 0, 0, 
+							g_set_error (error, 0, 0, "%s",  
 								     _("Empty field specified in foreign key constraint"));
 						}
 					}
 				}
 				g_string_append (string, ") REFERENCES ");
-				value = gda_server_operation_get_value_at (op, "/FKEY_S/%d/FKEY_REF_TABLE", i);
-				if (value && G_VALUE_HOLDS (value, G_TYPE_STRING) && g_value_get_string (value))
-					g_string_append (string, g_value_get_string (value));
+				tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider,
+										  "/FKEY_S/%d/FKEY_REF_TABLE", i);
+				if (tmp) {
+					g_string_append (string, tmp);
+					g_free (tmp);
+				}
 				else {
 					allok = FALSE;
-					g_set_error (error, 0, 0, _("No referenced table specified in foreign key constraint"));
+					g_set_error (error, 0, 0, "%s", _("No referenced table specified in foreign key constraint"));
 				}
 
 				g_string_append (string, " (");
 				for (j = 0; j < nbfields; j++) {
 					if (j != 0)
 						g_string_append (string, ", ");
-					value = gda_server_operation_get_value_at (op, 
-										   "/FKEY_S/%d/FKEY_FIELDS_A/@FK_REF_PK_FIELD/%d", i, j);
-					if (value && G_VALUE_HOLDS (value, G_TYPE_STRING) && g_value_get_string (value))
-						g_string_append (string, g_value_get_string (value));
+					tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider,
+											  "/FKEY_S/%d/FKEY_FIELDS_A/@FK_REF_PK_FIELD/%d", i, j);
+					if (tmp) {
+						g_string_append (string, tmp);
+						g_free (tmp);
+					}
 					else {
 						allok = FALSE;
-						g_set_error (error, 0, 0, 
+						g_set_error (error, 0, 0, "%s",  
 							     _("Empty referenced field specified in foreign key constraint"));
 					}
 				}
@@ -308,7 +325,7 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 
 	if (!hasfields) {
 		allok = FALSE;
-		g_set_error (error, 0, 0, _("Table to create must have at least one row"));
+		g_set_error (error, 0, 0, "%s", _("Table to create must have at least one row"));
 	}
 
 	/* other options */
@@ -317,7 +334,7 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 		if (value && G_VALUE_HOLDS (value, G_TYPE_STRING) && 
 		    g_value_get_string (value) && *g_value_get_string (value))
 			g_string_append (string, " ENGINE = ");
-			g_string_append (string, g_value_get_string (value));
+		g_string_append (string, g_value_get_string (value));
 		
 		value = gda_server_operation_get_value_at (op, "/TABLE_OPTIONS_P/TABLE_AUTOINC_VALUE");
 		if (value && G_VALUE_HOLDS (value, G_TYPE_INT)) 
@@ -334,11 +351,12 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 			g_string_append (string, " CHARACTER SET ");
 			g_string_append (string, g_value_get_string (value));
 
-			value = gda_server_operation_get_value_at (op, "/TABLE_OPTIONS_P/TABLE_COLLATION");
-			if (value && G_VALUE_HOLDS (value, G_TYPE_STRING) && 
-			    g_value_get_string (value) && *g_value_get_string (value)) {
+			tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider,
+									  "/TABLE_OPTIONS_P/TABLE_COLLATION");
+			if (tmp) {
 				g_string_append (string, " COLLATE ");
-				g_string_append (string, g_value_get_string (value));
+				g_string_append (string, tmp);
+				g_free (tmp);
 			}
 		}
 		
@@ -351,22 +369,24 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 		    g_value_get_string (value) && *g_value_get_string (value)) {
 			GdaDataHandler *dh;
 			gchar *str;
-
+			
 			dh = gda_server_provider_get_data_handler_g_type (provider, cnc, G_TYPE_STRING);
 			str = gda_data_handler_get_sql_from_value (dh, value);
-			g_string_append (string, " COMMENT = ");
-			g_string_append (string, str);
-			g_free (str);
+			if (str) {
+				g_string_append (string, " COMMENT = ");
+				g_string_append (string, str);
+				g_free (str);
+			}
 		}
-
+		
 		value = gda_server_operation_get_value_at (op, "/TABLE_OPTIONS_P/TABLE_MAX_ROWS");
 		if (value && G_VALUE_HOLDS (value, G_TYPE_INT)) 
 			g_string_append_printf (string, " MAX_ROWS = %d", g_value_get_int (value));
-
+		
 		value = gda_server_operation_get_value_at (op, "/TABLE_OPTIONS_P/TABLE_MIN_ROWS");
 		if (value && G_VALUE_HOLDS (value, G_TYPE_INT)) 
 			g_string_append_printf (string, " MIN_ROWS = %d", g_value_get_int (value));
-
+		
 		value = gda_server_operation_get_value_at (op, "/TABLE_DEF_P/TABLE_PACK_KEYS");
 		if (value && G_VALUE_HOLDS (value, G_TYPE_STRING) && 
 		    g_value_get_string (value) && *g_value_get_string (value)) {
@@ -382,9 +402,11 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 
 			dh = gda_server_provider_get_data_handler_g_type (provider, cnc, G_TYPE_STRING);
 			str = gda_data_handler_get_sql_from_value (dh, value);
-			g_string_append (string, " PASSWORD = ");
-			g_string_append (string, str);
-			g_free (str);
+			if (str) {
+				g_string_append (string, " PASSWORD = ");
+				g_string_append (string, str);
+				g_free (str);
+			}
 		}
 
 		value = gda_server_operation_get_value_at (op, "/TABLE_OPTIONS_P/TABLE_DELAY_KEY_WRITE");
@@ -420,9 +442,11 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 
 			dh = gda_server_provider_get_data_handler_g_type (provider, cnc, G_TYPE_STRING);
 			str = gda_data_handler_get_sql_from_value (dh, value);
-			g_string_append (string, " DATA_DIRECTORY = ");
-			g_string_append (string, str);
-			g_free (str);
+			if (str) {
+				g_string_append (string, " DATA_DIRECTORY = ");
+				g_string_append (string, str);
+				g_free (str);
+			}
 		}
 
 		value = gda_server_operation_get_value_at (op, "/TABLE_OPTIONS_P/TABLE_INDEX_DIR");
@@ -433,18 +457,17 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 
 			dh = gda_server_provider_get_data_handler_g_type (provider, cnc, G_TYPE_STRING);
 			str = gda_data_handler_get_sql_from_value (dh, value);
-			g_string_append (string, " INDEX_DIRECTORY = ");
-			g_string_append (string, str);
-			g_free (str);
+			if (str) {
+				g_string_append (string, " INDEX_DIRECTORY = ");
+				g_string_append (string, str);
+				g_free (str);
+			}
 		}
 	}
 
-	g_slist_free (pkfields);
-
-
 	sql = string->str;
 	g_string_free (string, FALSE);
-
+	
 	return sql;
 }
 
@@ -455,6 +478,7 @@ gda_mysql_render_DROP_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 	GString *string;
 	const GValue *value;
 	gchar *sql = NULL;
+	gchar *tmp;
 
 	string = g_string_new ("DROP");
 
@@ -468,10 +492,10 @@ gda_mysql_render_DROP_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 	if (value && G_VALUE_HOLDS (value, G_TYPE_BOOLEAN) && g_value_get_boolean (value))
 		g_string_append (string, " IF EXISTS");
 
-	value = gda_server_operation_get_value_at (op, "/TABLE_DESC_P/TABLE_NAME");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/TABLE_DESC_P/TABLE_NAME");
 	g_string_append_c (string, ' ');
-	g_string_append (string, g_value_get_string (value));
+	g_string_append (string, tmp);
+	g_free (tmp);
 
 	value = gda_server_operation_get_value_at (op, "/TABLE_DESC_P/REFERENCED_ACTION");
 	if (value && G_VALUE_HOLDS (value, G_TYPE_STRING)) {
@@ -490,19 +514,19 @@ gda_mysql_render_RENAME_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 			       GdaServerOperation *op, GError **error)
 {
 	GString *string;
-	const GValue *value;
 	gchar *sql = NULL;
+	gchar *tmp;
 
 	string = g_string_new ("ALTER TABLE ");
 
-	value = gda_server_operation_get_value_at (op, "/TABLE_DESC_P/TABLE_NAME");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
-	g_string_append (string, g_value_get_string (value));
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/TABLE_DESC_P/TABLE_NAME");
+	g_string_append (string, tmp);
+	g_free (tmp);
 
-	value = gda_server_operation_get_value_at (op, "/TABLE_DESC_P/TABLE_NEW_NAME");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/TABLE_DESC_P/TABLE_NEW_NAME");
 	g_string_append (string, " RENAME TO ");
-	g_string_append (string, g_value_get_string (value));
+	g_string_append (string, tmp);
+	g_free (tmp);
 
 	sql = string->str;
 	g_string_free (string, FALSE);
@@ -517,18 +541,19 @@ gda_mysql_render_ADD_COLUMN (GdaServerProvider *provider, GdaConnection *cnc,
 	GString *string;
 	const GValue *value;
 	gchar *sql = NULL;
+	gchar *tmp;
 
 	string = g_string_new ("ALTER TABLE ");
 
-	value = gda_server_operation_get_value_at (op, "/COLUMN_DEF_P/TABLE_NAME");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
-	g_string_append (string, g_value_get_string (value));
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/COLUMN_DEF_P/TABLE_NAME");
+	g_string_append (string, tmp);
+	g_free (tmp);
 
 	g_string_append (string, " ADD COLUMN ");
 
-	value = gda_server_operation_get_value_at (op, "/COLUMN_DEF_P/COLUMN_NAME");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
-	g_string_append (string, g_value_get_string (value));
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/COLUMN_DEF_P/COLUMN_NAME");
+	g_string_append (string, tmp);
+	g_free (tmp);
 
 	value = gda_server_operation_get_value_at (op, "/COLUMN_DEF_P/COLUMN_TYPE");
 	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
@@ -622,19 +647,19 @@ gda_mysql_render_DROP_COLUMN (GdaServerProvider *provider, GdaConnection *cnc,
 			      GdaServerOperation *op, GError **error)
 {
 	GString *string;
-	const GValue *value;
 	gchar *sql = NULL;
+	gchar *tmp;
 
 	string = g_string_new ("ALTER TABLE ");
 
-	value = gda_server_operation_get_value_at (op, "/COLUMN_DESC_P/TABLE_NAME");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
-	g_string_append (string, g_value_get_string (value));
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/COLUMN_DESC_P/TABLE_NAME");
+	g_string_append (string, tmp);
+	g_free (tmp);
 
-	value = gda_server_operation_get_value_at (op, "/COLUMN_DESC_P/COLUMN_NAME");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/COLUMN_DESC_P/COLUMN_NAME");
 	g_string_append (string, " DROP COLUMN ");
-	g_string_append (string, g_value_get_string (value));
+	g_string_append (string, tmp);
+	g_free (tmp);
 
 	sql = string->str;
 	g_string_free (string, FALSE);
@@ -652,6 +677,7 @@ gda_mysql_render_CREATE_INDEX (GdaServerProvider *provider, GdaConnection *cnc,
 	gchar *sql = NULL;
 	GdaServerOperationNode *node;
 	gint nrows, i;
+	gchar *tmp;
 
 	string = g_string_new ("CREATE ");
 
@@ -664,9 +690,9 @@ gda_mysql_render_CREATE_INDEX (GdaServerProvider *provider, GdaConnection *cnc,
 
 	g_string_append (string, "INDEX ");
 
-	value = gda_server_operation_get_value_at (op, "/INDEX_DEF_P/INDEX_NAME");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
-	g_string_append (string, g_value_get_string (value));
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/INDEX_DEF_P/INDEX_NAME");
+	g_string_append (string, tmp);
+	g_free (tmp);
 
 	value = gda_server_operation_get_value_at (op, "/INDEX_DEF_P/INDEX_METHOD");
 	if (value && G_VALUE_HOLDS (value, G_TYPE_STRING) && g_value_get_string (value)) {
@@ -676,10 +702,9 @@ gda_mysql_render_CREATE_INDEX (GdaServerProvider *provider, GdaConnection *cnc,
 
 	g_string_append (string, " ON ");
 	
-	value = gda_server_operation_get_value_at (op, "/INDEX_DEF_P/INDEX_ON_TABLE");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
-	g_string_append (string, g_value_get_string (value));
-
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/INDEX_DEF_P/INDEX_ON_TABLE");
+	g_string_append (string, tmp);
+	g_free (tmp);
 
 	/* fields or expressions the index is on */
 	g_string_append (string, " (");
@@ -687,11 +712,14 @@ gda_mysql_render_CREATE_INDEX (GdaServerProvider *provider, GdaConnection *cnc,
 	g_assert (node);
 	nrows = gda_server_operation_get_sequence_size (op, "/INDEX_FIELDS_S");
 	for (i = 0; i < nrows; i++) {
-		value = gda_server_operation_get_value_at (op, "/INDEX_FIELDS_S/%d/INDEX_FIELD", i);
-		if (value && G_VALUE_HOLDS (value, G_TYPE_STRING) && g_value_get_string (value)) {
+		tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider,
+								  "/INDEX_FIELDS_S/%d/INDEX_FIELD", i);
+                if (tmp) {
+
 			if (i != 0)
 				g_string_append (string, ", ");
-			g_string_append (string, g_value_get_string (value));
+			g_string_append (string, tmp);
+			g_free (tmp);
 			
 			value = gda_server_operation_get_value_at (op, "/INDEX_FIELDS_S/%d/INDEX_LENGTH", i);
 			if (value && G_VALUE_HOLDS (value, G_TYPE_INT) && (g_value_get_int (value) > 0))
@@ -718,19 +746,19 @@ gda_mysql_render_DROP_INDEX (GdaServerProvider *provider, GdaConnection *cnc,
 			     GdaServerOperation *op, GError **error)
 {
 	GString *string;
-	const GValue *value;
 	gchar *sql = NULL;
+	gchar *tmp;
 
 	string = g_string_new ("DROP INDEX ");
 
-	value = gda_server_operation_get_value_at (op, "/INDEX_DESC_P/INDEX_NAME");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
-	g_string_append (string, g_value_get_string (value));
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/INDEX_DESC_P/INDEX_NAME");
+	g_string_append (string, tmp);
+	g_free (tmp);
 
-	value = gda_server_operation_get_value_at (op, "/INDEX_DESC_P/INDEX_ON_TABLE");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/INDEX_DESC_P/INDEX_ON_TABLE");
 	g_string_append (string, " ON ");
-	g_string_append (string, g_value_get_string (value));
+	g_string_append (string, tmp);
+	g_free (tmp);
 
 	sql = string->str;
 	g_string_free (string, FALSE);
@@ -747,6 +775,7 @@ gda_mysql_render_CREATE_VIEW (GdaServerProvider *provider, GdaConnection *cnc,
 	gboolean allok = TRUE;
 	gchar *sql = NULL;
 	GdaServerOperationNode *node;
+	gchar *tmp;
 
 	string = g_string_new ("CREATE ");
 
@@ -755,10 +784,10 @@ gda_mysql_render_CREATE_VIEW (GdaServerProvider *provider, GdaConnection *cnc,
 		g_string_append (string, "OR REPLACE ");
 
 	g_string_append (string, "VIEW ");
-		
-	value = gda_server_operation_get_value_at (op, "/VIEW_DEF_P/VIEW_NAME");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
-	g_string_append (string, g_value_get_string (value));
+	
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/VIEW_DEF_P/VIEW_NAME");
+	g_string_append (string, tmp);
+	g_free (tmp);
 
 	node = gda_server_operation_get_node_info (op, "/FIELDS_A");
 	if (node) {
@@ -769,16 +798,19 @@ gda_mysql_render_CREATE_VIEW (GdaServerProvider *provider, GdaConnection *cnc,
 		for (i = 0; (i < nrows) && allok; i++) {
 			if (i == 0)
 				g_string_append (string, " (");
-			value = gda_server_operation_get_value_at (op, "/FIELDS_A/@COLUMN_NAME/%d", i);
-			if (value && G_VALUE_HOLDS (value, G_TYPE_STRING) && g_value_get_string (value)) {
+
+			tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider,
+									  "/FIELDS_A/@COLUMN_NAME/%d", i);
+			if (tmp) {
 				if (i != 0) 
 					g_string_append (string, ", ");
 				
-				g_string_append (string, g_value_get_string (value));
+				g_string_append (string, tmp);
 				g_string_append_c (string, ' ');
+				g_free (tmp);
 			}
 			else {
-				g_set_error (error, 0, 0, _("Incorrect specified column name"));
+				g_set_error (error, 0, 0, "%s", _("Incorrect specified column name"));
 				allok = FALSE;
 			}
 		}
@@ -812,6 +844,7 @@ gda_mysql_render_DROP_VIEW (GdaServerProvider *provider, GdaConnection *cnc,
 	GString *string;
 	const GValue *value;
 	gchar *sql = NULL;
+	gchar *tmp;
 
 	string = g_string_new ("DROP VIEW");
 
@@ -819,10 +852,10 @@ gda_mysql_render_DROP_VIEW (GdaServerProvider *provider, GdaConnection *cnc,
 	if (value && G_VALUE_HOLDS (value, G_TYPE_BOOLEAN) && g_value_get_boolean (value))
 		g_string_append (string, " IF EXISTS");
 
-	value = gda_server_operation_get_value_at (op, "/VIEW_DESC_P/VIEW_NAME");
-	g_assert (value && G_VALUE_HOLDS (value, G_TYPE_STRING));
+	tmp = gda_server_operation_get_sql_identifier_at (op, cnc, provider, "/VIEW_DESC_P/VIEW_NAME");
 	g_string_append_c (string, ' ');
-	g_string_append (string, g_value_get_string (value));
+	g_string_append (string, tmp);
+	g_free (tmp);
 
 	sql = string->str;
 	g_string_free (string, FALSE);
